#!/usr/bin/env python3

import unittest
import amulet


class TestDeploy(unittest.TestCase):
    """
    Basic deployment test for Apache Hadoop YARN Master.

    This charm cannot do anything useful by itself, so integration testing
    is done in the bundle.
    """

    @classmethod
    def setUpClass(cls):
        cls.d = amulet.Deployment(series='trusty')
        cls.d.add('apache-hadoop-yarn-master')
        cls.d.setup(timeout=9000)
        cls.d.sentry.wait()
        cls.unit = cls.d.sentry.unit['apache-hadoop-yarn-master/0']

    def test_deploy(self):
        output, retcode = self.unit.run("pgrep -a java")
        assert 'ResourceManager' not in output, "ResourceManager should not be started"
        assert 'JobHistoryServer' not in output, "JobHistoryServer should not be started"
        assert 'NodeManager' not in output, "NodeManager should not be started"
        assert 'NameNode' not in output, "NameNode should not be started"
        assert 'SecondaryNameNode' not in output, "SecondaryNameNode should not be started"
        assert 'DataNode' not in output, "DataServer should not be started"

    def test_dist_config(self):
        # test_dist_config.py is run on the deployed unit because it
        # requires the Juju context to properly validate dist.yaml
        output, retcode = self.unit.run("tests/remote/test_dist_config.py")
        self.assertEqual(retcode, 0, 'Remote dist config test failed:\n{}'.format(output))


if __name__ == '__main__':
    unittest.main()
